@@ -5,6 +5,7 @@ data
 )
 
 {
+
 # varying intercept at first position
     arg <- strsplit(gsub(" ", "", formula[length(formula)]), "\\+")
     int <- if (grepl("v\\(1",arg)==TRUE) 0 else 1
@@ -15,7 +16,7 @@ data
         }
 
 # model.frame
-    special <- c("v","p")
+    special <- c("v", "p", "grouped", "grouped.fused", "sp", "SCAD", "elastic", "vspline")
     m <- model.frame(formula=terms(formula, specials=special, data=data), data)
     if (nrow(m) == 0)
         stop("No (non-missing) observations")
@@ -27,12 +28,25 @@ data
     if (int==0) X <- X[,-1]
 
     namen <- colnames(X)
+    namen <- sub(",", ".", namen, fixed=TRUE)
     namen <- gsub(" ", "", namen, fixed=TRUE)
+    namen <- sub("vspline(", "", namen, fixed=TRUE)
     namen <- sub("v(", "", namen, fixed=TRUE)
+    namen <- sub("sp(", "", namen, fixed=TRUE)
     namen <- sub("p(", "", namen, fixed=TRUE)
+    namen <- sub("grouped(", "", namen, fixed=TRUE)
+    namen <- sub("grouped.fused(", "", namen, fixed=TRUE)
+    namen <- sub("SCAD(", "", namen, fixed=TRUE)
+    namen <- sub("elastic(", "", namen, fixed=TRUE)
     namen <- gsub("(", "", namen, fixed=TRUE)
     namen <- gsub(")", "", namen, fixed=TRUE)
-    namen <- sub(",", ".", namen, fixed=TRUE)
+    namen <- gsub("n=", "", namen, fixed=TRUE)
+    namen <- gsub("TRUE", "", namen, fixed=TRUE)
+    namen <- gsub("FALSE", "", namen, fixed=TRUE)
+    namen <- gsub(",", "", namen, fixed=TRUE)    
+    namen <- gsub("bj=", "", namen, fixed=TRUE)
+    namen <- gsub("knots=", "", namen, fixed=TRUE)
+    namen <- gsub("\"", "", namen)#, fixed=TRUE)
     colnames(X) <- namen
 
 # formula
