@@ -52,7 +52,7 @@ offset = rep(0, nobs),
     valideta <- unless.null(family$valideta, function(eta) TRUE)
     validmu <- unless.null(family$validmu, function(mu) TRUE)
     
-    coefold <- if (nvars >= nobs || control$start.ml==TRUE) control$oml else rep(0, nvars) # rep(1, nvars)?!?
+    coefold <- if (nvars >= nobs || control$start.ml==TRUE) control$oml else rep(1, nvars) # rep(1, nvars) fur brd
     if (any(is.na(coefold))) coefold[which(is.na(coefold))] <- 0
         
     mustart <- etastart <- NULL
@@ -156,7 +156,7 @@ offset = rep(0, nobs),
             grouped <- function(beta, Aj, control=control) { # Aj matrix, dim(Aj)= q x Lj
               dfj <- sum(Aj==1) # dim(a_l)= q x 1
               AjtAj <- Aj%*%t(Aj)
-              nbs <- t(Aj)%*%beta
+              # nbs <- t(Aj)%*%beta
               rep(sqrt(dfj) / sqrt(t(beta)%*%AjtAj%*%beta + control$c), ncol(Aj) ) # Lj vector
               }
 
@@ -168,7 +168,8 @@ offset = rep(0, nobs),
               # for (i in c("grouped")){
                 for (j in grep(i, info[[2]])) {
                     good <- which(which.a==info[[2]][j])
-                    output[good] <- eval(parse(text=i))(beta, acoefs[,good], control)
+                    adpt <-  sqrt(sum((t(acoefs)%*%control$oml)[good]^2)) * control$adapted.weights + abs(control$adapted.weights - 1) 
+                    output[good] <- eval(parse(text=i))(beta, acoefs[,good], control)/adpt
                 }    
               #}          
               return(output) 
@@ -178,8 +179,10 @@ offset = rep(0, nobs),
         A <- function(beta, acoefs=acoefs, x=x, which.a=which.a, all.L=all.L, lambda=lambda, phis=phis, weight=weight, control=control) {
           nbs <- t(acoefs)%*%beta
           fd <- as.integer(drop(nbs)!=0)
-          appro <- fd* lambda * phis * weight * (vec.L(nbs, which.a, all.L, control) + vec.special(beta, acoefs, which.a)) 
-          acoefs %*% diag(appro, ncol=length(appro), nrow=length(appro)) %*% t(acoefs)
+          appro <- fd * lambda * phis * weight * (vec.L(nbs, which.a, all.L, control) + vec.special(beta, acoefs, which.a))
+#          acoefs %*% diag(appro, ncol=length(appro), nrow=length(appro)) %*% t(acoefs)
+          crossprod(t(acoefs)*sqrt(appro))
+
           }
             
     # P-IRLS
@@ -336,8 +339,8 @@ offset = rep(0, nobs),
       
       H.i.1 <- Matrix(x.star) 
           suppressWarnings(try(H.i.2 <- H.i.1 %*% inv.pimat.new))
-      rank <-  if (exists("H.i.2")) sum(H.i.2 * H.i.1) else  NA
-      
+      rank <-  if (exists("H.i.2")) sum(H.i.2 * H.i.1) else  NA  # equivalently: rank <-  sum(diag(H.i.2 %*% t(H.i.1)))
+     
 } # Ende Fall mit Kovariablen
 
 # formatiere ergebnis
@@ -358,11 +361,11 @@ nulldf <- n.ok - 1
 resdf <- n.ok - rank   # df(error)
 aic.model <- aic(y, nobs, mu, weights, dev) + 2 * rank
 
-try(QR <- qr(diag(sqrt(weights))%*%x))
-try(QR$tol <- control$epsilon)
-try(Rmat <- qr.R(QR))
-try(effects <- qr.qty(QR, w*z))
-#Rmat <- QR <- NULL
+#try(QR <- qr(diag(sqrt(weights))%*%x))
+#try(QR$tol <- control$epsilon)
+#try(Rmat <- qr.R(QR))
+#try(effects <- qr.qty(QR, w*z))
+Rmat <- QR <- NULL
 
 # output
 list(coefficients = coef, residuals = residuals, fitted.values = mu,
